@@ -85,25 +85,25 @@ static void free_interface(gpointer data)
 	g_free(interface);
 }
 
-static connman_bool_t ether_blacklisted(const char *name)
+static bool ether_blacklisted(const char *name)
 {
-	if (name == NULL)
-		return TRUE;
+	if (!name)
+		return true;
 
-	if (__connman_device_isfiltered(name) == TRUE)
-		return TRUE;
+	if (__connman_device_isfiltered(name))
+		return true;
 
-	return FALSE;
+	return false;
 }
 
-static connman_bool_t wext_interface(char *ifname)
+static bool wext_interface(char *ifname)
 {
 	struct iwreq wrq;
 	int fd, err;
 
 	fd = socket(PF_INET, SOCK_DGRAM | SOCK_CLOEXEC, 0);
 	if (fd < 0)
-		return FALSE;
+		return false;
 
 	memset(&wrq, 0, sizeof(wrq));
 	strncpy(wrq.ifr_name, ifname, IFNAMSIZ);
@@ -113,18 +113,18 @@ static connman_bool_t wext_interface(char *ifname)
 	close(fd);
 
 	if (err < 0)
-		return FALSE;
+		return false;
 
-	return TRUE;
+	return true;
 }
 
 static void read_uevent(struct interface_data *interface)
 {
 	char *filename, line[128];
-	connman_bool_t found_devtype;
+	bool found_devtype;
 	FILE *f;
 
-	if (ether_blacklisted(interface->name) == TRUE) {
+	if (ether_blacklisted(interface->name)) {
 		interface->service_type = CONNMAN_SERVICE_TYPE_UNKNOWN;
 		interface->device_type = CONNMAN_DEVICE_TYPE_UNKNOWN;
 	} else {
@@ -139,22 +139,22 @@ static void read_uevent(struct interface_data *interface)
 
 	g_free(filename);
 
-	if (f == NULL)
+	if (!f)
 		return;
 
-	found_devtype = FALSE;
+	found_devtype = false;
 	while (fgets(line, sizeof(line), f)) {
 		char *pos;
 
 		pos = strchr(line, '\n');
-		if (pos == NULL)
+		if (!pos)
 			continue;
 		pos[0] = '\0';
 
 		if (strncmp(line, "DEVTYPE=", 8) != 0)
 			continue;
 
-		found_devtype = TRUE;
+		found_devtype = true;
 
 		if (strcmp(line + 8, "wlan") == 0) {
 			interface->service_type = CONNMAN_SERVICE_TYPE_WIFI;
@@ -165,9 +165,6 @@ static void read_uevent(struct interface_data *interface)
 		} else if (strcmp(line + 8, "bluetooth") == 0) {
 			interface->service_type = CONNMAN_SERVICE_TYPE_BLUETOOTH;
 			interface->device_type = CONNMAN_DEVICE_TYPE_BLUETOOTH;
-		} else if (strcmp(line + 8, "wimax") == 0) {
-			interface->service_type = CONNMAN_SERVICE_TYPE_WIMAX;
-			interface->device_type = CONNMAN_DEVICE_TYPE_WIMAX;
 		} else if (strcmp(line + 8, "gadget") == 0) {
 			interface->service_type = CONNMAN_SERVICE_TYPE_GADGET;
 			interface->device_type = CONNMAN_DEVICE_TYPE_GADGET;
@@ -199,7 +196,7 @@ enum connman_device_type __connman_rtnl_get_device_type(int index)
 
 	interface = g_hash_table_lookup(interface_list,
 					GINT_TO_POINTER(index));
-	if (interface == NULL)
+	if (!interface)
 		return CONNMAN_DEVICE_TYPE_UNKNOWN;
 
 	return interface->device_type;
@@ -221,7 +218,7 @@ unsigned int connman_rtnl_add_newlink_watch(int index,
 	struct watch_data *watch;
 
 	watch = g_try_new0(struct watch_data, 1);
-	if (watch == NULL)
+	if (!watch)
 		return 0;
 
 	watch->id = ++watch_id;
@@ -286,7 +283,7 @@ static void trigger_rtnl(int index, void *user_data)
 			__connman_ipconfig_get_gateway_from_index(index,
 					CONNMAN_IPCONFIG_TYPE_ALL);
 
-		if (gateway != NULL)
+		if (gateway)
 			rtnl->newgateway(index, gateway);
 	}
 }
@@ -356,10 +353,10 @@ static const char *operstate2str(unsigned char operstate)
 	return "";
 }
 
-static void extract_link(struct ifinfomsg *msg, int bytes,
+static bool extract_link(struct ifinfomsg *msg, int bytes,
 				struct ether_addr *address, const char **ifname,
 				unsigned int *mtu, unsigned char *operstate,
-						struct rtnl_link_stats *stats)
+				struct rtnl_link_stats *stats)
 {
 	struct rtattr *attr;
 
@@ -367,30 +364,34 @@ static void extract_link(struct ifinfomsg *msg, int bytes,
 					attr = RTA_NEXT(attr, bytes)) {
 		switch (attr->rta_type) {
 		case IFLA_ADDRESS:
-			if (address != NULL)
+			if (address)
 				memcpy(address, RTA_DATA(attr), ETH_ALEN);
 			break;
 		case IFLA_IFNAME:
-			if (ifname != NULL)
+			if (ifname)
 				*ifname = RTA_DATA(attr);
 			break;
 		case IFLA_MTU:
-			if (mtu != NULL)
+			if (mtu)
 				*mtu = *((unsigned int *) RTA_DATA(attr));
 			break;
 		case IFLA_STATS:
-			if (stats != NULL)
+			if (stats)
 				memcpy(stats, RTA_DATA(attr),
 					sizeof(struct rtnl_link_stats));
 			break;
 		case IFLA_OPERSTATE:
-			if (operstate != NULL)
+			if (operstate)
 				*operstate = *((unsigned char *) RTA_DATA(attr));
 			break;
 		case IFLA_LINKMODE:
 			break;
+		case IFLA_WIRELESS:
+			return false;
 		}
 	}
+
+	return true;
 }
 
 static void process_newlink(unsigned short type, int index, unsigned flags,
@@ -407,7 +408,8 @@ static void process_newlink(unsigned short type, int index, unsigned flags,
 	GSList *list;
 
 	memset(&stats, 0, sizeof(stats));
-	extract_link(msg, bytes, &address, &ifname, &mtu, &operstate, &stats);
+	if (!extract_link(msg, bytes, &address, &ifname, &mtu, &operstate, &stats))
+		return;
 
 	snprintf(ident, 13, "%02x%02x%02x%02x%02x%02x",
 						address.ether_addr_octet[0],
@@ -429,6 +431,7 @@ static void process_newlink(unsigned short type, int index, unsigned flags,
 	case ARPHRD_ETHER:
 	case ARPHRD_LOOPBACK:
 	case ARPHDR_PHONET_PIPE:
+	case ARPHRD_PPP:
 	case ARPHRD_NONE:
 		__connman_ipconfig_newlink(index, type, flags,
 							str, mtu, &stats);
@@ -445,7 +448,7 @@ static void process_newlink(unsigned short type, int index, unsigned flags,
 						operstate2str(operstate));
 
 	interface = g_hash_table_lookup(interface_list, GINT_TO_POINTER(index));
-	if (interface == NULL) {
+	if (!interface) {
 		interface = g_new0(struct interface_data, 1);
 		interface->index = index;
 		interface->name = g_strdup(ifname);
@@ -456,10 +459,8 @@ static void process_newlink(unsigned short type, int index, unsigned flags,
 
 		if (type == ARPHRD_ETHER)
 			read_uevent(interface);
-
-		__connman_technology_add_interface(interface->service_type,
-			interface->index, interface->name, interface->ident);
-	}
+	} else
+		interface = NULL;
 
 	for (list = rtnl_list; list; list = list->next) {
 		struct connman_rtnl *rtnl = list->data;
@@ -468,6 +469,16 @@ static void process_newlink(unsigned short type, int index, unsigned flags,
 			rtnl->newlink(type, index, flags, change);
 	}
 
+	/*
+	 * The interface needs to be added after the newlink call.
+	 * The newlink will create the technology when needed and
+	 * __connman_technology_add_interface() expects the
+	 * technology to be there already.
+	 */
+	if (interface)
+		__connman_technology_add_interface(interface->service_type,
+			interface->index, interface->name, interface->ident);
+
 	for (list = watch_list; list; list = list->next) {
 		struct watch_data *watch = list->data;
 
@@ -488,7 +499,8 @@ static void process_dellink(unsigned short type, int index, unsigned flags,
 	GSList *list;
 
 	memset(&stats, 0, sizeof(stats));
-	extract_link(msg, bytes, NULL, &ifname, NULL, &operstate, &stats);
+	if (!extract_link(msg, bytes, NULL, &ifname, NULL, &operstate, &stats))
+		return;
 
 	if (operstate != 0xff)
 		connman_info("%s {dellink} index %d operstate %u <%s>",
@@ -525,19 +537,19 @@ static void extract_ipv4_addr(struct ifaddrmsg *msg, int bytes,
 					attr = RTA_NEXT(attr, bytes)) {
 		switch (attr->rta_type) {
 		case IFA_ADDRESS:
-			if (address != NULL)
+			if (address)
 				*address = *((struct in_addr *) RTA_DATA(attr));
 			break;
 		case IFA_LOCAL:
-			if (local != NULL)
+			if (local)
 				*local = *((struct in_addr *) RTA_DATA(attr));
 			break;
 		case IFA_BROADCAST:
-			if (broadcast != NULL)
+			if (broadcast)
 				*broadcast = *((struct in_addr *) RTA_DATA(attr));
 			break;
 		case IFA_LABEL:
-			if (label != NULL)
+			if (label)
 				*label = RTA_DATA(attr);
 			break;
 		}
@@ -554,11 +566,11 @@ static void extract_ipv6_addr(struct ifaddrmsg *msg, int bytes,
 					attr = RTA_NEXT(attr, bytes)) {
 		switch (attr->rta_type) {
 		case IFA_ADDRESS:
-			if (addr != NULL)
+			if (addr)
 				*addr = *((struct in6_addr *) RTA_DATA(attr));
 			break;
 		case IFA_LOCAL:
-			if (local != NULL)
+			if (local)
 				*local = *((struct in6_addr *) RTA_DATA(attr));
 			break;
 		}
@@ -589,7 +601,7 @@ static void process_newaddr(unsigned char family, unsigned char prefixlen,
 		return;
 	}
 
-	if (inet_ntop(family, src, ip_string, INET6_ADDRSTRLEN) == NULL)
+	if (!inet_ntop(family, src, ip_string, INET6_ADDRSTRLEN))
 		return;
 
 	__connman_ipconfig_newaddr(index, family, label,
@@ -602,11 +614,7 @@ static void process_newaddr(unsigned char family, unsigned char prefixlen,
 		 * have now properly configured interface with proper
 		 * autoconfigured address.
 		 */
-		char *interface = connman_inet_ifname(index);
-
-		__connman_resolver_redo_servers(interface);
-
-		g_free(interface);
+		__connman_resolver_redo_servers(index);
 	}
 }
 
@@ -634,7 +642,7 @@ static void process_deladdr(unsigned char family, unsigned char prefixlen,
 		return;
 	}
 
-	if (inet_ntop(family, src, ip_string, INET6_ADDRSTRLEN) == NULL)
+	if (!inet_ntop(family, src, ip_string, INET6_ADDRSTRLEN))
 		return;
 
 	__connman_ipconfig_deladdr(index, family, label,
@@ -651,15 +659,15 @@ static void extract_ipv4_route(struct rtmsg *msg, int bytes, int *index,
 					attr = RTA_NEXT(attr, bytes)) {
 		switch (attr->rta_type) {
 		case RTA_DST:
-			if (dst != NULL)
+			if (dst)
 				*dst = *((struct in_addr *) RTA_DATA(attr));
 			break;
 		case RTA_GATEWAY:
-			if (gateway != NULL)
+			if (gateway)
 				*gateway = *((struct in_addr *) RTA_DATA(attr));
 			break;
 		case RTA_OIF:
-			if (index != NULL)
+			if (index)
 				*index = *((int *) RTA_DATA(attr));
 			break;
 		}
@@ -676,16 +684,16 @@ static void extract_ipv6_route(struct rtmsg *msg, int bytes, int *index,
 					attr = RTA_NEXT(attr, bytes)) {
 		switch (attr->rta_type) {
 		case RTA_DST:
-			if (dst != NULL)
+			if (dst)
 				*dst = *((struct in6_addr *) RTA_DATA(attr));
 			break;
 		case RTA_GATEWAY:
-			if (gateway != NULL)
+			if (gateway)
 				*gateway =
 					*((struct in6_addr *) RTA_DATA(attr));
 			break;
 		case RTA_OIF:
-			if (index != NULL)
+			if (index)
 				*index = *((int *) RTA_DATA(attr));
 			break;
 		}
@@ -1064,20 +1072,20 @@ static void rtnl_route(struct nlmsghdr *hdr)
 	}
 }
 
-static connman_bool_t is_route_rtmsg(struct rtmsg *msg)
+static bool is_route_rtmsg(struct rtmsg *msg)
 {
 
 	if (msg->rtm_table != RT_TABLE_MAIN)
-		return FALSE;
+		return false;
 
 	if (msg->rtm_protocol != RTPROT_BOOT &&
 			msg->rtm_protocol != RTPROT_KERNEL)
-		return FALSE;
+		return false;
 
 	if (msg->rtm_type != RTN_UNICAST)
-		return FALSE;
+		return false;
 
-	return TRUE;
+	return true;
 }
 
 static void rtnl_newroute(struct nlmsghdr *hdr)
@@ -1186,7 +1194,7 @@ static void rtnl_newnduseropt(struct nlmsghdr *hdr)
 	struct in6_addr *servers = NULL;
 	int i, nr_servers = 0;
 	int msglen = msg->nduseropt_opts_len;
-	char *interface;
+	int index;
 
 	DBG("family %d index %d len %d type %d code %d",
 		msg->nduseropt_family, msg->nduseropt_ifindex,
@@ -1198,8 +1206,8 @@ static void rtnl_newnduseropt(struct nlmsghdr *hdr)
 			msg->nduseropt_icmp_code != 0)
 		return;
 
-	interface = connman_inet_ifname(msg->nduseropt_ifindex);
-	if (!interface)
+	index = msg->nduseropt_ifindex;
+	if (index < 0)
 		return;
 
 	for (opt = (void *)&msg[1];
@@ -1220,7 +1228,7 @@ static void rtnl_newnduseropt(struct nlmsghdr *hdr)
 								sizeof(buf)))
 					continue;
 
-				connman_resolver_append_lifetime(interface,
+				connman_resolver_append_lifetime(index,
 							NULL, buf, lifetime);
 			}
 
@@ -1228,14 +1236,13 @@ static void rtnl_newnduseropt(struct nlmsghdr *hdr)
 			g_free(domains);
 
 			domains = rtnl_nd_opt_dnssl(opt, &lifetime);
-			for (i = 0; domains != NULL && domains[i] != NULL; i++)
-				connman_resolver_append_lifetime(interface,
+			for (i = 0; domains && domains[i]; i++)
+				connman_resolver_append_lifetime(index,
 						domains[i], NULL, lifetime);
 		}
 	}
 
 	g_free(domains);
-	g_free(interface);
 }
 
 static const char *type2string(uint16_t type)
@@ -1335,13 +1342,13 @@ static int process_response(guint32 seq)
 	DBG("seq %d", seq);
 
 	req = find_request(seq);
-	if (req != NULL) {
+	if (req) {
 		request_list = g_slist_remove(request_list, req);
 		g_free(req);
 	}
 
 	req = g_slist_nth_data(request_list, 0);
-	if (req == NULL)
+	if (!req)
 		return 0;
 
 	return send_request(req);
@@ -1404,8 +1411,7 @@ static void rtnl_message(void *buf, size_t len)
 	}
 }
 
-static gboolean netlink_event(GIOChannel *chan,
-				GIOCondition cond, gpointer data)
+static gboolean netlink_event(GIOChannel *chan, GIOCondition cond, gpointer data)
 {
 	unsigned char buf[4096];
 	struct sockaddr_nl nladdr;
@@ -1450,7 +1456,7 @@ static int send_getlink(void)
 	DBG("");
 
 	req = g_try_malloc0(RTNL_REQUEST_SIZE);
-	if (req == NULL)
+	if (!req)
 		return -ENOMEM;
 
 	req->hdr.nlmsg_len = RTNL_REQUEST_SIZE;
@@ -1470,7 +1476,7 @@ static int send_getaddr(void)
 	DBG("");
 
 	req = g_try_malloc0(RTNL_REQUEST_SIZE);
-	if (req == NULL)
+	if (!req)
 		return -ENOMEM;
 
 	req->hdr.nlmsg_len = RTNL_REQUEST_SIZE;
@@ -1490,7 +1496,7 @@ static int send_getroute(void)
 	DBG("");
 
 	req = g_try_malloc0(RTNL_REQUEST_SIZE);
-	if (req == NULL)
+	if (!req)
 		return -ENOMEM;
 
 	req->hdr.nlmsg_len = RTNL_REQUEST_SIZE;
@@ -1561,7 +1567,7 @@ unsigned int __connman_rtnl_update_interval_remove(unsigned int interval)
 
 	update_list = g_slist_remove(update_list, GINT_TO_POINTER(interval));
 
-	if (update_list != NULL)
+	if (update_list)
 		min = GPOINTER_TO_UINT(g_slist_nth_data(update_list, 0));
 
 	if (min > update_interval)
